pub enum ApiBackend {
Auto,
AVFoundation,
Video4Linux,
UniversalVideoClass,
MediaFoundation,
OpenCv,
GStreamer,
Network,
Browser,
}Expand description
The list of known capture backends to the library.
AUTOis special - it tells the Camera struct to automatically choose a backend most suited for the current platform.AVFoundation- UsesAVFoundationonMacOSXVideo4Linux-Video4Linux2, a linux specific backend.UniversalVideoClass- DEPRECATED Universal Video Class (please check libuvc). Platform agnostic, although on linux it needssudopermissions or similar to use.MediaFoundation- Microsoft Media Foundation, Windows only,OpenCv- UsesOpenCVto capture. Platform agnostic.GStreamer- DEPRECATED UsesGStreamerRTP to capture. Platform agnostic.Network- UsesOpenCVto capture from an IP.Browser- Uses browser APIs to capture from a webcam.
Variants