pub enum FrameFormat {
MJPEG,
YUYV,
NV12,
GRAY,
RAWRGB,
RAWBGR,
}Expand description
Describes a frame format (i.e. how the bytes themselves are encoded). Often called FourCC.
- YUYV is a mathematical color space. You can read more here.
- NV12 is same as above. Note that a partial compression (e.g. [16, 235] may be coerced to [0, 255].
- MJPEG is a motion-jpeg compressed frame, it allows for high frame rates.
- GRAY is a grayscale image format, usually for specialized cameras such as IR Cameras.
- RAWRGB is a Raw RGB888 format.
Variants