pub enum RequestedFormatType {
AbsoluteHighestResolution,
AbsoluteHighestFrameRate,
HighestResolution(Resolution),
HighestFrameRate(u32),
Exact(CameraFormat),
Closest(CameraFormat),
None,
}Expand description
Tells the init function what camera format to pick.
AbsoluteHighestResolution: Pick the highestResolution, then pick the highest frame rate of those provided.AbsoluteHighestFrameRate: Pick the highest frame rate, then the highestResolution.HighestResolution(Option<u32>): Pick the highestResolutionfor the given framerate (theOption<u32>). If itsNone, it will pick the highest possibleResolutionHighestFrameRate(Option<Resolution>): Pick the highest frame rate for the givenResolution(theOption<Resolution>). If it isNone, it will pick the highest possinle framerate.Exact: Pick the exactCameraFormatprovided.Closest: Pick the closestCameraFormatprovided in order ofFrameFormat,Resolution, and FPS. Note that if theFrameFormatdoes not exist, this will fail to resolve.None: Pick a randomCameraFormat
Variants
AbsoluteHighestResolution
AbsoluteHighestFrameRate
HighestResolution(Resolution)
HighestFrameRate(u32)
Exact(CameraFormat)
Closest(CameraFormat)
None