buf_yuyv422_to_rgb

Function buf_yuyv422_to_rgb 

pub fn buf_yuyv422_to_rgb(
    data: &[u8],
    dest: &mut [u8],
    rgba: bool,
) -> Result<(), NokhwaError>
Same as yuyv422_to_rgb but with a destination buffer instead of a return Vec<u8>

Errors

If the stream is invalid YUYV, or the destination buffer is not large enough, this will error.