CameraControl

Struct CameraControl 

pub struct CameraControl { /* private fields */ }
This struct tells you everything about a particular KnownCameraControl.

However, you should never need to instantiate this struct, since its usually generated for you by nokhwa. The only time you should be modifying this struct is when you need to set a value and pass it back to the camera. NOTE: Assume the values for min and max as non-inclusive!. E.g. if the CameraControl says min is 100, the minimum is actually 101.

Implementations

Source

impl CameraControl

pub fn new( control: KnownCameraControl, name: String, description: ControlValueDescription, flag: Vec<KnownCameraControlFlag>, active: bool, ) -> CameraControl

Creates a new CameraControl

pub fn name(&self) -> &str

Gets the name of this CameraControl

pub fn description(&self) -> &ControlValueDescription

pub fn value(&self) -> ControlValueSetter

pub fn control(&self) -> KnownCameraControl

pub fn flag(&self) -> &[KnownCameraControlFlag]

Gets the KnownCameraControlFlag of this CameraControl, telling you weather this control is automatically set or manually set.

pub fn active(&self) -> bool

Gets active of this CameraControl, telling you weather this control is currently active(in-use).

pub fn set_active(&mut self, active: bool)

Gets active of this CameraControl, telling you weather this control is currently active(in-use).