pub struct CameraFormat { /* private fields */ }Expand description
This is a convenience struct that holds all information about the format of a webcam stream.
It consists of a Resolution, FrameFormat, and a frame rate(u8).
Implementations
Sourceimpl CameraFormat
impl CameraFormat
Sourcepub fn new(
resolution: Resolution,
format: FrameFormat,
frame_rate: u32,
) -> CameraFormat
pub fn new( resolution: Resolution, format: FrameFormat, frame_rate: u32, ) -> CameraFormat
Construct a new CameraFormat
Sourcepub fn new_from(
res_x: u32,
res_y: u32,
format: FrameFormat,
fps: u32,
) -> CameraFormat
pub fn new_from( res_x: u32, res_y: u32, format: FrameFormat, fps: u32, ) -> CameraFormat
CameraFormat::new(), but raw.
Sourcepub fn resolution(&self) -> Resolution
pub fn resolution(&self) -> Resolution
Get the resolution of the current CameraFormat
Sourcepub fn width(&self) -> u32
pub fn width(&self) -> u32
Get the width of the resolution of the current CameraFormat
Sourcepub fn height(&self) -> u32
pub fn height(&self) -> u32
Get the height of the resolution of the current CameraFormat
Sourcepub fn set_resolution(&mut self, resolution: Resolution)
pub fn set_resolution(&mut self, resolution: Resolution)
Set the CameraFormat’s resolution.
Sourcepub fn frame_rate(&self) -> u32
pub fn frame_rate(&self) -> u32
Get the frame rate of the current CameraFormat
Sourcepub fn set_frame_rate(&mut self, frame_rate: u32)
pub fn set_frame_rate(&mut self, frame_rate: u32)
Set the CameraFormat’s frame rate.
Sourcepub fn format(&self) -> FrameFormat
pub fn format(&self) -> FrameFormat
Get the CameraFormat’s format.
Sourcepub fn set_format(&mut self, format: FrameFormat)
pub fn set_format(&mut self, format: FrameFormat)
Set the CameraFormat’s format.