pub enum ControlValueDescription {
None,
Integer {
value: i64,
default: i64,
step: i64,
},
IntegerRange {
min: i64,
max: i64,
value: i64,
step: i64,
default: i64,
},
Float {
value: f64,
default: f64,
step: f64,
},
FloatRange {
min: f64,
max: f64,
value: f64,
step: f64,
default: f64,
},
Boolean {
value: bool,
default: bool,
},
String {
value: String,
default: Option<String>,
},
Bytes {
value: Vec<u8>,
default: Vec<u8>,
},
KeyValuePair {
key: i128,
value: i128,
default: (i128, i128),
},
Point {
value: (f64, f64),
default: (f64, f64),
},
Enum {
value: i64,
possible: Vec<i64>,
default: i64,
},
RGB {
value: (f64, f64, f64),
max: (f64, f64, f64),
default: (f64, f64, f64),
},
}Expand description
The values for a CameraControl.
This provides a wide range of values that can be used to control a camera.
Variants
Implementations
Sourceimpl ControlValueDescription
impl ControlValueDescription
Sourcepub fn value(&self) -> ControlValueSetter
pub fn value(&self) -> ControlValueSetter
Get the value of this ControlValueDescription
Sourcepub fn verify_setter(&self, setter: &ControlValueSetter) -> bool
pub fn verify_setter(&self, setter: &ControlValueSetter) -> bool
Verifies if the setter is valid for the provided ControlValueDescription.
true=> Is valid.false=> Is not valid.
If the step is 0, it will automatically return true.