pub fn yuyv422_to_rgb(data: &[u8], rgba: bool) -> Result<Vec<u8>, NokhwaError>Expand description
Converts a YUYV 4:2:2 datastream to a RGB888 Stream. For further reading
Errors
This may error when the data stream size is not divisible by 4, a i32 -> u8 conversion fails, or it fails to read from a certain index.